Revert "Wifi usability: Change the unit of the threshold for tx/rx throughput from Mbps to Kbps"

This reverts commit 078fe45552425c18aa8052da0ae3c9205fa5c309.

Reason for revert: This change introduced a bug and it completely changed the functionality of WiFi data stall detection, e.g., high Tx link speed can easily trigger data stall.  We would like to roll back them to restore the normal functionality of Wifi data stall detection.

Bug: 141995185

Change-Id: I024808b580955545b084112c4b14921f038b595f
Merged-In: I078d28ed81a84e32aaece839a51590364a974481
(cherry picked from commit 038345da61cb9d560486386a1c46c18c870e597c)
diff --git a/proto/src/wifi.proto b/proto/src/wifi.proto
index fbf6ca5..353a187 100644
--- a/proto/src/wifi.proto
+++ b/proto/src/wifi.proto
@@ -1798,12 +1798,12 @@
   optional int32 data_stall_duration_ms = 5;
 
   // Threshold of Tx throughput below which to trigger a data stall
-  // measured in Kbps
-  optional int32 data_stall_tx_tput_thr_kbps = 6;
+  // measured in Mbps
+  optional int32 data_stall_tx_tput_thr_mbps = 6;
 
   // Threshold of Rx throughput below which to trigger a data stall
-  // measured in Kbps
-  optional int32 data_stall_rx_tput_thr_kbps = 7;
+  // measured in Mbps
+  optional int32 data_stall_rx_tput_thr_mbps = 7;
 
   // Threshold of Tx packet error rate above which to trigger a data stall
   // in percentage